<?php
/**
 * Aster Gym Trainer functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Aster Gym Trainer
 */

function aster_gym_trainer_enqueue_styles() {
    //wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()) . '/assets/css/bootstrap.css');
    $aster_gym_trainer_parentcss = 'dark-fitness-style';
    $aster_gym_trainer_theme = wp_get_theme(); wp_enqueue_style( $aster_gym_trainer_parentcss, get_template_directory_uri() . '/style.css', array(), $aster_gym_trainer_theme->parent()->get('Version'));
    wp_enqueue_style( 'aster-gym-trainer-style', get_stylesheet_uri(), array( $aster_gym_trainer_parentcss ), $aster_gym_trainer_theme->get('Version'));

    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
}

add_action( 'wp_enqueue_scripts', 'aster_gym_trainer_enqueue_styles' );

if ( ! function_exists( 'aster_gym_trainer_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function aster_gym_trainer_setup() {

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
                'style',
                'script',
                'woocommerce',
            )
        );

        // Set up the WordPress core custom background feature.
        add_theme_support(
            'custom-background',
            apply_filters(
                'aster_gym_trainer_custom_background_args',
                array(
                    'default-color' => 'ffffff',
                    'default-image' => '',
                )
            )
        );

        // Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height'      => 250,
                'width'       => 250,
                'flex-width'  => true,
                'flex-height' => true,
            )
        );

        /**
         * Add theme support for gutenberg block.
         */
        add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );
    }
endif;
add_action( 'after_setup_theme', 'aster_gym_trainer_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function aster_gym_trainer_widgets_init() {
    register_sidebar(
        array(
            'name'          => esc_html__( 'Sidebar', 'aster-gym-trainer' ),
            'id'            => 'sidebar-1',
            'description'   => esc_html__( 'Add widgets here.', 'aster-gym-trainer' ),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h2 class="widget-title"><span>',
            'after_title'   => '</span></h2>',
        )
    );

    // Regsiter 4 footer widgets.
    register_sidebars(
        4,
        array(
            /* translators: %d: Footer Widget count. */
            'name'          => esc_html__( 'Footer Widget %d', 'aster-gym-trainer' ),
            'id'            => 'footer-widget',
            'description'   => esc_html__( 'Add widgets here.', 'aster-gym-trainer' ),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h6 class="widget-title"><span>',
            'after_title'   => '</span></h6>',
        )
    );
}
add_action( 'widgets_init', 'aster_gym_trainer_widgets_init' );

function aster_gym_trainer_remove_customize_register() {
    global $wp_customize;
    $wp_customize->remove_section( 'upsell_section' );
}
add_action( 'customize_register', 'aster_gym_trainer_remove_customize_register', 11 );